@@ -225,7 +225,8 @@ class SBSPlotter(BSPlotter):
         return plt
 
     @styled_plot(sumo_base_style, sumo_bs_style)
-    def get_projected_plot(self, selection, mode='rgb', interpolate_factor=4,
+    def get_projected_plot(self, selection, mode='rgb', normalise="all",
+                           interpolate_factor=4,
                            circle_size=150, projection_cutoff=0.001,
                            zero_to_efermi=True, ymin=-6., ymax=6., width=None,
                            height=None, vbm_cbm_marker=False,
@@ -284,6 +285,15 @@ class SBSPlotter(BSPlotter):
                         the composition of the band. The size of the circles
                         can be scaled using the ``circle_size`` option.
 
+            normalise (:obj:`str`, optional): Normalisation the projections.
+                Options are:
+
+                  * ``'all'``: Projections normalised against the sum of all
+                       other projections.
+                  * ``'select'``: Projections normalised against the sum of the
+                       selected projections.
+                  * ``None``: No normalisation performed.
+
             interpolate_factor (:obj:`int`, optional): The factor by which to
                 interpolate the band structure (necessary to make smooth
                 lines). A larger number indicates greater interpolation.
@@ -401,7 +411,7 @@ class SBSPlotter(BSPlotter):
         elif spin is Spin.down:
             spins = [spins[1]]
 
-        proj = get_projections_by_branches(self.bs, selection, normalise='select')
+        proj = get_projections_by_branches(self.bs, selection, normalise=normalise)
 
         # nd is branch index
         for spin, nd in it.product(spins, range(nbranches)):
@@ -414,14 +424,20 @@ class SBSPlotter(BSPlotter):
             bands = bands[mask]
             weights = [proj[nd][i][spin][mask] for i in range(len(selection))]
 
-            # interpolate band structure to improve smoothness
-            temp_dists = np.linspace(distances[0], distances[-1],
-                                     len(distances) * interpolate_factor)
-            bands = interp1d(distances, bands, axis=1, bounds_error=False,
-                             fill_value="extrapolate")(temp_dists)
-            weights = interp1d(distances, weights, axis=2, bounds_error=False,
-                               fill_value="extrapolate")(temp_dists)
-            distances = temp_dists
+            if len(distances) > 2: # Only interpolate if it makes sense to do so
+                # interpolate band structure to improve smoothness
+                temp_dists = np.linspace(distances[0], distances[-1],
+                                         len(distances) * interpolate_factor)
+                bands = interp1d(distances, bands, axis=1, bounds_error=False,
+                                 fill_value="extrapolate")(temp_dists)
+                weights = interp1d(distances, weights, axis=2, bounds_error=False,
+                                   fill_value="extrapolate")(temp_dists)
+                distances = temp_dists
+
+            else: # change from list to array if we skipped the scipy interpolation
+                weights = np.array(weights)
+                bands = np.array(bands)
+                distances = np.array(distances)
 
             # sometimes VASP produces very small negative weights
             weights[weights < 0] = 0
@@ -657,13 +673,5 @@ class SBSPlotter(BSPlotter):
 
         ax.set_xticks(unique_d)
         ax.set_xticklabels(unique_l)
-        ax.xaxis.grid(True, ls='-')
+        ax.xaxis.grid(True)
         ax.set_ylabel(ylabel)
-
-        trans_xdata_yaxes = blended_transform_factory(ax.transData,
-                                                      ax.transAxes)
-        ax.vlines(unique_d, 0, 1,
-                  transform=trans_xdata_yaxes,
-                  colors=rcParams['grid.color'],
-                  linewidth=rcParams['grid.linewidth'],
-                  zorder=3)
